Package {tidygapminder}


Type: Package
Title: Easily Tidy Gapminder Datasets
Version: 1.0.0
Description: A toolset that allows you to easily import and tidy data sheets retrieved from Gapminder data web tools. It will therefore contribute to reduce the time used in data cleaning of Gapminder indicator data sheets as they are very messy.
Depends: R (≥ 4.1.0)
Imports: readxl, tibble
Suggests: testthat (≥ 3.0.0), covr, knitr, rmarkdown
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
Config/testthat/edition: 3
URL: https://ebedthan.github.io/tidygapminder/
BugReports: https://github.com/ebedthan/tidygapminder/issues
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-16 17:03:07 UTC; ediman
Author: Anicet Ebou ORCID iD [aut, cre]
Maintainer: Anicet Ebou <anicet.ebou@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-16 21:30:02 UTC

Tidy Gapminder indicator data sheets stored in a folder.

Description

Applies tidy_index to all Gapminder data sheets found in a directory and optionally combines them into a single data frame.

Usage

tidy_bunch(dirpath = ".", combine = FALSE, ...)

Arguments

dirpath

Path to folder containing indices Gapminder indicator data sheets. Defaults to the current working directory.

combine

A boolean. If TRUE, combines all tidied data sheets into a single data frame joined on country and year. Default: FALSE.

...

Additional arguments (reserved for future use).

Value

If combine = FALSE (default), a named list of tibbles, one per file. If combine = TRUE, a single tibble with all indicators merged by country and year.

Examples

folder_path <- system.file("extdata", package = "tidygapminder")

tidy_bunch(folder_path)
tidy_bunch(folder_path, combine = TRUE)


Tidy a Gapminder indicator data sheet.

Description

Tidy a Gapminder indicator data sheet.

Usage

tidy_index(filepath)

tidy_indice(filepath)

Arguments

filepath

Path to a Gapminder indicator data sheet (.csv, .xlsx, or .xls).

Value

The indicator data sheet as a tidy data frame with columns country, year, and the indicator name.

Examples

csv_filepath <- system.file("extdata/life_expectancy_years.csv",
                             package = "tidygapminder")
xlsx_filepath <- system.file(
                 "extdata/agriculture_land.xlsx",
                 package = "tidygapminder")

tidy_index(csv_filepath)
tidy_index(xlsx_filepath)